Class: Qt::MetaMethod
Constant Summary collapse
- Method =
Oops, name clash with the Signal module so hard code this value rather than get it from the Smoke runtime
Qt::Enum.new(0, "QMetaMethod::MethodType")
- Signal =
Qt::Enum.new(1, "QMetaMethod::MethodType")